# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.4]
### Fixed
- Global permissions check in Checker now uses default auth backends.

## [0.1.3]
### Added
- Checker permission gatherers.

## [0.1.2]
### Added
- Permissions gatherers.

## [0.1.1]
### Added
- Checkers Registry mechanics.

## [0.1.0]
Initial version.
